//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Access/DataPropertyWidget.cpp
//! @brief     Defines class DataPropertyWidget.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2022
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Access/DataPropertyWidget.h"
#include "Base/Axis/Frame.h"
#include "Base/Util/Assert.h"
#include "GUI/Model/Data/DataItem.h"
#include "GUI/Model/Device/DatafileItem.h"
#include "GUI/Model/Device/InstrumentItems.h"
#include "GUI/Model/Job/JobItem.h"
#include "GUI/Model/Project/ProjectDocument.h"

DataPropertyWidget::DataPropertyWidget()
    : m_main_layout(new QFormLayout(this))
{
    setWindowTitle("Properties");

    m_main_layout->setContentsMargins(8, 20, 8, 8);
    m_main_layout->setSpacing(5);
}

void DataPropertyWidget::setJobOrDatafileItem(QObject* item)
{
    setBaseItem(item);
    createPanelElements();
}

void DataPropertyWidget::updateItemCoords(DataItem* item)
{
    if (!item)
        return;

    emit item->axesUnitsReplotRequested();
    updateUIValues();
}

void DataPropertyWidget::updateUIValues()
{
    if (jobRealBase())
        for (const auto& updater : m_updaters)
            updater();
}
