//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Data/StackedFrames.cpp
//! @brief     Implements class StackedFrames and children
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Data/StackedFrames.h"
#include "Base/Util/Assert.h"
#include "GUI/Model/Data/Data1DItem.h"
#include "GUI/Model/Data/Data2DItem.h"
#include "GUI/Model/Job/JobItem.h"
#include "GUI/View/Frame/Fit1DFrame.h"
#include "GUI/View/Frame/Fit2DFrame.h"
#include "GUI/View/Frame/Plot2DFrame.h"
#include "GUI/View/Frame/SpecularFrame.h"

StackedFrames::StackedFrames()
{
    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
}

void StackedFrames::setStackedItem(QObject* item)
{
    if (!item) {
        hide();
        return;
    }

    QWidget* widget;
    auto it = m_item_to_widget.find(item);
    if (it != m_item_to_widget.end()) {
        widget = it.value();
    } else {
        widget = newWidget(item);

        addWidget(widget);
        m_item_to_widget[item] = widget;
    }

    setCurrentWidget(widget);
    widget->show();
    show();
}

QWidget* StackedDataFrames::newWidget(QObject* obj) const
{
    if (auto* item = dynamic_cast<Data1DItem*>(obj))
        return new SpecularFrame(item);
    else if (auto* item = dynamic_cast<Data2DItem*>(obj))
        return new Plot2DFrame(item);
    else
        ASSERT_NEVER;
}

QWidget* StackedJobFrames::newWidget(QObject* obj) const
{
    if (auto* item = dynamic_cast<Data1DItem*>(obj))
        return new SpecularFrame(item);
    else if (auto* item = dynamic_cast<Data2DItem*>(obj))
        return new Plot2DFrame(item);
    else if (auto* item = dynamic_cast<JobItem*>(obj)) {
        if (item->rank() == 1)
            return new Fit1DFrame(item);
        else if (item->rank() == 2)
            return new Fit2DFrame(item);
    }
    ASSERT_NEVER;
}
