//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/InstrumentLibraryDialog.h
//! @brief     Defines class InstrumentLibraryDialog.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_INSTRUMENT_INSTRUMENTLIBRARYDIALOG_H
#define BORNAGAIN_GUI_VIEW_INSTRUMENT_INSTRUMENTLIBRARYDIALOG_H

#include "GUI/View/Instrument/InstrumentsTreeModel.h"
#include "GUI/View/Widget/GroupBoxes.h"
#include <QDialog>
#include <QDialogButtonBox>
#include <QScrollArea>
#include <QTreeView>

class InstrumentItem;
class InstrumentLibrary;

class InstrumentLibraryDialog : public QDialog {
    Q_OBJECT
public:
    InstrumentLibraryDialog(QWidget* parent, InstrumentLibrary* instrumentLibrary);
    ~InstrumentLibraryDialog() override;

    //! Execute the dialog for choosing an instrument from the library.
    //! Returns nullptr if canceled
    InstrumentItem* execChoose();

    //! Execute the dialog to add an instrument to the library.
    void execAdd(const InstrumentItem& instrumentToAdd);

private:
    void onItemDoubleClickedForChoose(const QModelIndex& index);
    void onCurrentChangedForChoose();
    QList<QAction*> getOverlayActions(const QModelIndex& index, bool asHover);

    void onInstrumentNameEdited(const QString& newName);
    void onInstrumentDescriptionEdited(const QString& t);

    InstrumentLibrary* m_instrument_library;
    InstrumentsTreeModel* m_tree_model;
    InstrumentItem* m_chosen_item;

    QTreeView* m_tree_view;
    QDialogButtonBox* m_button_box;
};

#endif // BORNAGAIN_GUI_VIEW_INSTRUMENT_INSTRUMENTLIBRARYDIALOG_H
