//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Setup/AxisPanel.cpp
//! @brief     Implements class AxisPanel.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Setup/AxisPanel.h"
#include "GUI/Model/Axis/AmplitudeAxisItem.h"
#include "GUI/Model/Axis/BasicAxisItem.h"
#include "GUI/Model/Data/Data1DItem.h"
#include "GUI/Model/Project/ProjectDocument.h"
#include "GUI/Support/Data/ComboProperty.h"
#include "GUI/View/Numeric/DoubleSpinBox.h"
#include "GUI/View/Numeric/NumWidgetUtil.h"
#include "GUI/View/Tool/LayoutUtil.h"
#include "GUI/View/Widget/GroupBoxes.h"
#include <QAction>
#include <QCheckBox>
#include <QFormLayout>
#include <QLineEdit>

void AxisPanel::createPanelElements()
{
    if (allData1DItems().empty())
        return;

    for (auto* item : allData1DItems())
        disconnect(item, nullptr, this, nullptr);

    GUI::Util::Layout::clearLayout(m_main_layout);
    m_updaters.clear();

    /*
    m_main_layout->addRow("Axes units:",
                         GUI::Util::createUnitsComboBox(
                             axesUnitsList(),
                             [this] { return currentData1DItem()->currentAxesUnits(); },
                             [this](const QString& newVal) {
                                 for (auto item : allData1DItems())
                                     item->setCurrentAxesUnits(newVal);
                                 emit axesRangeResetRequested();
                                 gDoc->setModified();
                             },
                             &m_updaters));
    */

    // -- x-axis
    auto* xGroup = new StaticGroupBox("X axis", this);
    auto* xFormLayout = new QFormLayout(xGroup->body());
    xFormLayout->setContentsMargins(0, 0, 0, 0);
    xFormLayout->setSpacing(5);

    xFormLayout->addRow("Min:", GUI::Util::createDoubleSpinBox(
                                    [this] { return currentData1DItem()->axItemX()->min(); },
                                    [this](double newValue) {
                                        for (auto* item : allData1DItems())
                                            item->axItemX()->setMin(newValue);
                                        gDoc->setModified();
                                    },
                                    &m_updaters));

    xFormLayout->addRow("Max:", GUI::Util::createDoubleSpinBox(
                                    [this] { return currentData1DItem()->axItemX()->max(); },
                                    [this](double newValue) {
                                        for (auto* item : allData1DItems())
                                            item->axItemX()->setMax(newValue);
                                        gDoc->setModified();
                                    },
                                    &m_updaters));

    m_main_layout->addRow(xGroup);

    // -- y-axis
    auto* yGroup = new StaticGroupBox("Y axis", this);
    auto* yFormLayout = new QFormLayout(yGroup->body());
    yFormLayout->setContentsMargins(0, 0, 0, 0);
    yFormLayout->setSpacing(5);

    auto* logRangeSpinBox = GUI::Util::createDoubleSpinBox(
        [this] { return currentData1DItem()->axItemY()->logRangeOrders(); },
        [this](double newValue) {
            for (auto* item : mainData1DItems()) {
                item->axItemY()->setLogRangeOrders(newValue);
                updateUIValues();
            }
            gDoc->setModified();
        },
        &m_updaters, "Dynamic range to display values", RealLimits::positive());

    yFormLayout->addRow("Min:", GUI::Util::createDoubleSpinBox(
                                    [this] { return currentData1DItem()->axItemY()->min(); },
                                    [this](double newValue) {
                                        for (auto* item : mainData1DItems()) {
                                            item->axItemY()->setMin(newValue);
                                            item->axItemY()->adjustLogRangeOrders();
                                            updateUIValues();
                                        }
                                        gDoc->setModified();
                                    },
                                    &m_updaters));

    yFormLayout->addRow("Max:", GUI::Util::createDoubleSpinBox(
                                    [this] { return currentData1DItem()->axItemY()->max(); },
                                    [this](double newValue) {
                                        for (auto* item : mainData1DItems()) {
                                            item->axItemY()->setMax(newValue);
                                            item->axItemY()->adjustLogRangeOrders();
                                            updateUIValues();
                                        }
                                        gDoc->setModified();
                                    },
                                    &m_updaters));

    yFormLayout->addRow(GUI::Util::createCheckBox(
        "log10", [this] { return currentData1DItem()->axItemY()->isLogScale(); },
        [this, logRangeSpinBox](bool b) {
            logRangeSpinBox->setEnabled(b);
            for (auto* item : allData1DItems())
                item->axItemY()->setLogScale(b);
            gDoc->setModified();
        },
        &m_updaters));

    yFormLayout->addRow("Log range:", logRangeSpinBox);

    m_main_layout->addRow(yGroup);

    updateUIValues();

    // react on external changes (e.g. zooming in customplot shall update the axis values)
    connect(currentData1DItem(), &DataItem::itemAxesRangeChanged, this, &AxisPanel::updateUIValues,
            Qt::UniqueConnection);

    // update coordinates on axes units change
    for (auto* item : allData1DItems())
        connect(item, &DataItem::axesUnitsChanged, this, &AxisPanel::updateItemCoords,
                Qt::UniqueConnection);
}
